DebugLogger class

Stores and exposes in-app debug logs shown in the overlay.

Constructors

DebugLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() → void
Removes all stored log entries.
getLogs() List<String>
Returns the stored log entries in reverse chronological order.
log(String message) → void
Adds a new log entry to the in-app log store.